# Python API

::: xyz2graph.graph.MolGraph
    options:
        show_root_heading: false        # Don't show "MolGraph" as a heading
        show_root_toc_entry: false      # Don't include the class name in the table of contents
        members_order: source           # Order methods/properties as they appear in source code
        separate_signature: true        # Show function signatures separately from docstrings
        show_signature_annotations: true # Show type hints and return types
        heading_level: 3  
